@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------
 #  notebook.tcl
 #  This file is part of Unifix BWidget Toolkit
-#  $Id: notebook.tcl,v 1.19 2003/10/20 21:23:52 damonc Exp $
+#  $Id: notebook.tcl,v 1.25.2.1 2009/08/10 11:28:50 oehhar Exp $
 # ---------------------------------------------------------------------------
 #  Index of commands:
 #     - NoteBook::create
@@ -302,6 +302,7 @@ proc NoteBook::delete { path page {destroyframe 1} } {
     }
     if { $destroyframe } {
         destroy $path.f$page
+        unset data($page,width) data($page,realized)
     }
     _redraw $path
 }
@@ -333,7 +334,7 @@ proc NoteBook::itemcget { path page option } {
 # ---------------------------------------------------------------------------
 proc NoteBook::bindtabs { path event script } {
     if { $script != "" } {
-	append script " \[NoteBook::_get_page_name [list $path] current 2\]"
+	append script " \[NoteBook::_get_page_name [list $path] current 1\]"
         $path.c bind "page" $event $script
     } else {
         $path.c bind "page" $event {}
@@ -503,6 +504,7 @@ proc NoteBook::_itemconfigure { path page lres } {
          $state == "disabled" && $data(select) == $page } {
         set data(select) ""
     }
+    _set_help $path $page
     return $res
 }
 
@@ -791,6 +793,8 @@ proc NoteBook::_draw_page { path page create } {
     if {$bd < 1} { set bd 1 }
 
     if { $tabsOnBottom } {
+	# adjust to keep bottom edge in view
+	incr h1 -1
 	set top [expr {$top * -1}]
 	set topPlusRadius [expr {$topPlusRadius * -1}]
 	# Hrm... the canvas has an issue with drawing diagonal segments
